libbraiding: Computing with braids
==================================

Description
-----------

libbraiding is a library to compute several properties of braids,
including centralizer and conjugacy check.

License
-------

GPLv3+


SPKG Maintainers
----------------

-  Miguel Marco


Upstream Contact
----------------

Miguel Marco (mmarco@unizar.es)
